@@ -11,6 +11,9 @@ import functools
 import inspect
 import re
 
+from time import time
+
+
 
 # try:
 # from tornado.web import _UIModuleNamespace
@@ -107,10 +110,14 @@ def model(method):
 
         self.db = self.handler.db
         self.acct_db = self.handler.acct_db
-        self.dbs = self.handler.dbs
 
         self.debug = self.handler.debug
-        self.cache_db = self.handler.cache_db
+
+        if hasattr(self.handler,"dbs"):
+            self.dbs = self.handler.dbs
+
+        if hasattr(self.handler,"cache_db"):
+            self.cache_db = self.handler.cache_db
 
         return method(self, *args, **kwargs)
 
@@ -251,7 +258,18 @@ class RequestHandler(tornado.web.RequestHandler):
 
         self.api_messages = self.application.settings.get('api_messages', {})
 
-        self.app_version = self.application.settings.get('version', None)
+        self.project_version = self.application.settings.get('version', None)
+        self.project_name = self.application.settings.get('project', None)
+
+        self.css_version = self.application.settings.get('css_version', str(int(time())))
+        self.js_version = self.application.settings.get('js_version', str(int(time())))
+
+
+        self.favicon = self.application.settings.get('favicon', "/static/favicon.ico")
+        self.copyright_text = self.application.settings.get('copyright_text', '')
+        self.copyright = self.application.settings.get('copyright', '')
+        self.author = self.application.settings.get('author', '')
+
 
         # ez-hack-end
 
@@ -305,7 +323,13 @@ class RequestHandler(tornado.web.RequestHandler):
             'cdn': self.cdn,
             'hacking_ie': self.hacking_ie,
             'debug': int(self.debug),
-            'app_version': self.app_version
+            'project_version': self.project_version,
+            'project_name': self.project_name,
+            'author': self.author,
+            'copyright':self.copyright,
+            'copyright_text':self.copyright_text,
+            'js_version':self.js_version,
+            'css_version':self.css_version
         })
 
         return namespace
@@ -345,7 +369,8 @@ class RequestHandler(tornado.web.RequestHandler):
         return None
 
 
-    def post_redirect(self, url, msg, breads_title=[], breads_url=[], rec_title=[], rec_url=[], *args, **kwargs):
+    def post_redirect(self, url, msg, breadcrumbs=[], recommend=[], *args, **kwargs):
+
         """
         don't use get to set argument
         :param url:
@@ -373,6 +398,19 @@ class RequestHandler(tornado.web.RequestHandler):
         #
         # redirect_url = url + data_str
 
+        try:
+            breads_title, breads_url = zip(*breadcrumbs)
+            self.set_cookie('rt_breads_title', url_escape('|'.join(breads_title)))
+            self.set_cookie('rt_breads_url', url_escape('|'.join(breads_url)))
+        except:
+            pass
+
+        try:
+            rec_title, rec_url = zip(*(recommend))
+            self.set_cookie('rt_rec_title', url_escape('|'.join(rec_title)))
+            self.set_cookie('rt_rec_url', url_escape('|'.join(rec_url)))
+        except:
+            pass
 
         for k, v in kwargs.items():
             if isinstance(v, list):
@@ -381,10 +419,6 @@ class RequestHandler(tornado.web.RequestHandler):
                 self.set_cookie('rt_' + k, url_escape(v))
             pass
 
-        self.set_cookie('rt_rec_title', url_escape('|'.join(rec_title)))
-        self.set_cookie('rt_rec_url', url_escape('|'.join(rec_url)))
-        self.set_cookie('rt_breads_title', url_escape('|'.join(breads_title)))
-        self.set_cookie('rt_breads_url', url_escape('|'.join(breads_url)))
         self.set_cookie('rt_msg', url_escape(msg))
         self.redirect(url)
         pass
@@ -398,3 +432,6 @@ class RequestHandler(tornado.web.RequestHandler):
 
 pass
 
+
+
+
